==> 1.0.1.tar.gz: lib/src/mock_base.dart <==
import 'dart:math';

import 'package:intl/intl.dart';

part 'package:dart_mock/src/data/city.dart';
part 'package:dart_mock/src/random/address.dart';
part 'package:dart_mock/src/random/base.dart';
part 'package:dart_mock/src/random/color.dart';
part 'package:dart_mock/src/random/date.dart';
part 'package:dart_mock/src/random/helper.dart';
part 'package:dart_mock/src/random/image.dart';
part 'package:dart_mock/src/random/miscellaneous.dart';
part 'package:dart_mock/src/random/name.dart';
part 'package:dart_mock/src/random/text.dart';
part 'package:dart_mock/src/random/web.dart';

/// random object.
Random _random = Random();

/// max int value, equal to 2^63-1.
const int maxInteger = 9223372036854775807;

/// lower case letters.
const String lower = 'abcdefghijklmnopqrstuvwxyz';

/// upper case letters.
const String upper = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';

/// numbers.
const String number = '0123456789';

/// symbols.
const String symbol = '!@#\$%^&*()[]';

/// chinese regions.
const regions = ['东北', '华北', '华东', '华中', '华南', '西南', '西北'];

/// max dateTime, equal 2099-12-31 23:59:59:999.
const int maxDate = 4102415999999;

/// common ad image sizes.
const List<String> sizes = [
  '300x250',
  '250x250',
  '240x400',
  '336x280',
  '180x150',
  '720x300',
  '468x60',
  '234x60',
  '88x31',
  '120x90',
  '120x60',
  '120x240',
  '125x125',
  '728x90',
  '160x600',
  '120x600',
  '300x600'
];

/// Beyond the top 1000 names, from 'http://www.ssa.gov/oact/babynames/limits.html'.
const List<String> firstNames = [
  // male
  'James',
  'John',
  'Robert',
  'Michael',
  'William',
  'David',
  'Richard',
  'Charles',
  'Joseph',
  'Thomas',
  'Christopher',
  'Daniel',
  'Paul',
  'Mark',
  'Donald',
  'George',
  'Kenneth',
  'Steven',
  'Edward',
  'Brian',
  'Ronald',
  'Anthony',
  'Kevin',
  'Jason',
  'Matthew',
  'Gary',
  'Timothy',
  'Jose',
  'Larry',
  'Jeffrey',
  'Frank',
  'Scott',
  'Eric',
  // female
  'Mary',
  'Patricia',
  'Linda',
  'Barbara',
  'Elizabeth',
  'Jennifer',
  'Maria',
  'Susan',
  'Margaret',
  'Dorothy',
  'Lisa',
  'Nancy',
  'Karen',
  'Betty',
  'Helen',
  'Sandra',
  'Donna',
  'Carol',
  'Ruth',
  'Sharon',
  'Michelle',
  'Laura',
  'Sarah',
  'Kimberly',
  'Deborah',
  'Jessica',
  'Shirley',
  'Cynthia',
  'Angela',
  'Melissa',
  'Brenda',
  'Amy',
  'Anna'
];

// common english lastName.
const List<String> lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Brown',
  'Jones',
  'Miller',
  'Davis',
  'Garcia',
  'Rodriguez',
  'Wilson',
  'Martinez',
  'Anderson',
  'Taylor',
  'Thomas',
  'Hernandez',
  'Moore',
  'Martin',
  'Jackson',
  'Thompson',
  'White',
  'Lopez',
  'Lee',
  'Gonzalez',
  'Harris',
  'Clark',
  'Lewis',
  'Robinson',
  'Walker',
  'Perez',
  'Hall',
  'Young',
  'Allen'
];

/// common chinese firstName, from 'http://www.name999.net/xingming/xingshi/20131004/48.html'.
const List<String> cfirstNames = [
  '伟',
  '芳',
  '娜',
  '秀英',
  '敏',
  '静',
  '丽',
  '强',
  '磊',
  '军',
  '洋',
  '勇',
  '艳',
  '杰',
  '娟',
  '涛',
  '明',
  '超',
  '秀兰',
  '霞',
  '平',
  '刚',
  '桂英'
];

/// common chinese lastName, from (http://baike.baidu.com/view/1719115.htm' and 'http://xuanpai.sinaapp.com'.
const List<String> clastNames = [
  '王',
  '李',
  '张',
  '刘',
  '陈',
  '杨',
  '赵',
  '黄',
  '周',
  '吴',
  '徐',
  '孙',
  '胡',
  '朱',
  '高',
  '林',
  '何',
  '郭',
  '马',
  '罗',
  '梁',
  '宋',
  '郑',
  '谢',
  '韩',
  '唐',
  '冯',
  '于',
  '董',
  '萧',
  '程',
  '曹',
  '袁',
  '邓',
  '许',
  '傅',
  '沈',
  '曾',
  '彭',
  '吕',
  '苏',
  '卢',
  '蒋',
  '蔡',
  '贾',
  '丁',
  '魏',
  '薛',
  '叶',
  '阎',
  '余',
  '潘',
  '杜',
  '戴',
  '夏',
  '锺',
  '汪',
  '田',
  '任',
  '姜',
  '范',
  '方',
  '石',
  '姚',
  '谭',
  '廖',
  '邹',
  '熊',
  '金',
  '陆',
  '郝',
  '孔',
  '白',
  '崔',
  '康',
  '毛',
  '邱',
  '秦',
  '江',
  '史',
  '顾',
  '侯',
  '邵',
  '孟',
  '龙',
  '万',
  '段',
  '雷',
  '钱',
  '汤',
  '尹',
  '黎',
  '易',
  '常',
  '武',
  '乔',
  '贺',
  '赖',
  '龚',
  '文'
];

/// Commonly used 500 Chinese characters, from 'http://baike.baidu.com/view/568436.htm'.
const String chineseCharacters =
    '的一是在不了有和人这中大为上个国我以要他时来用们生到作地于出就分对成会可主发年动同工也能下过子说产种面而方后多定行学法所民得经十三之进着等部度家电力里如水化高自二理起小物现实加量都两体制机当使点从业本去把性好应开它合还因由其些然前外天政四日那社义事平形相全表间样与关各重新线内数正心反你明看原又么利比或但质气第向道命此变条只没结解问意建月公无系军很情者最立代想已通并提直题党程展五果料象员革位入常文总次品式活设及管特件长求老头基资边流路级少图山统接知较将组见计别她手角期根论运农指几九区强放决西被干做必战先回则任取据处队南给色光门即保治北造百规热领七海口东导器压志世金增争济阶油思术极交受联什认六共权收证改清己美再采转更单风切打白教速花带安场身车例真务具万每目至达走积示议声报斗完类八离华名确才科张信马节话米整空元况今集温传土许步群广石记需段研界拉林律叫且究观越织装影算低持音众书布复容儿须际商非验连断深难近矿千周委素技备半办青省列习响约支般史感劳便团往酸历市克何除消构府称太准精值号率族维划选标写存候毛亲快效斯院查江型眼王按格养易置派层片始却专状育厂京识适属圆包火住调满县局照参红细引听该铁价严龙飞';

/// common protocols.
const List<String> protocols = [
  'http',
  'https',
  'ftp',
  'gopher',
  'mailto',
  'mid',
  'cid',
  'news',
  'nntp',
  'prospero',
  'telnet',
  'rlogin',
  'tn3270',
  'wais'
];

/// common tlds, from 'http://www.163ns.com/zixun/post/4417.html'.
const List<String> tlds = [
  // common
  "com",
  "net",
  "org",
  "edu",
  "gov",
  "int",
  "mil",
  "cn",
  // domestic
  "com.cn",
  "net.cn",
  "gov.cn",
  "org.cn",
  // chinese tlds.
  "中国",
  "中国互联.公司",
  "中国互联.网络",
  // new international tlds.
  "tel",
  "biz",
  "cc",
  "tv",
  "info",
  "name",
  "hk",
  "mobi",
  "asia",
  "cd",
  "travel",
  "pro",
  "museum",
  "coop",
  "aero",
  // other country or territory tlds.
  "ad",
  "ae",
  "af",
  "ag",
  "ai",
  "al",
  "am",
  "an",
  "ao",
  "aq",
  "ar",
  "as",
  "at",
  "au",
  "aw",
  "az",
  "ba",
  "bb",
  "bd",
  "be",
  "bf",
  "bg",
  "bh",
  "bi",
  "bj",
  "bm",
  "bn",
  "bo",
  "br",
  "bs",
  "bt",
  "bv",
  "bw",
  "by",
  "bz",
  "ca",
  "cc",
  "cf",
  "cg",
  "ch",
  "ci",
  "ck",
  "cl",
  "cm",
  "cn",
  "co",
  "cq",
  "cr",
  "cu",
  "cv",
  "cx",
  "cy",
  "cz",
  "de",
  "dj",
  "dk",
  "dm",
  "do",
  "dz",
  "ec",
  "ee",
  "eg",
  "eh",
  "es",
  "et",
  "ev",
  "fi",
  "fj",
  "fk",
  "fm",
  "fo",
  "fr",
  "ga",
  "gb",
  "gd",
  "ge",
  "gf",
  "gh",
  "gi",
  "gl",
  "gm",
  "gn",
  "gp",
  "gr",
  "gt",
  "gu",
  "gw",
  "gy",
  "hk",
  "hm",
  "hn",
  "hr",
  "ht",
  "hu",
  "id",
  "ie",
  "il",
  "in",
  "io",
  "iq",
  "ir",
  "is",
  "it",
  "jm",
  "jo",
  "jp",
  "ke",
  "kg",
  "kh",
  "ki",
  "km",
  "kn",
  "kp",
  "kr",
  "kw",
  "ky",
  "kz",
  "la",
  "lb",
  "lc",
  "li",
  "lk",
  "lr",
  "ls",
  "lt",
  "lu",
  "lv",
  "ly",
  "ma",
  "mc",
  "md",
  "mg",
  "mh",
  "ml",
  "mm",
  "mn",
  "mo",
  "mp",
  "mq",
  "mr",
  "ms",
  "mt",
  "mv",
  "mw",
  "mx",
  "my",
  "mz",
  "na",
  "nc",
  "ne",
  "nf",
  "ng",
  "ni",
  "nl",
  "no",
  "np",
  "nr",
  "nt",
  "nu",
  "nz",
  "om",
  "qa",
  "pa",
  "pe",
  "pf",
  "pg",
  "ph",
  "pk",
  "pl",
  "pm",
  "pn",
  "pr",
  "pt",
  "pw",
  "py",
  "re",
  "ro",
  "ru",
  "rw",
  "sa",
  "sb",
  "sc",
  "sd",
  "se",
  "sg",
  "sh",
  "si",
  "sj",
  "sk",
  "sl",
  "sm",
  "sn",
  "so",
  "sr",
  "st",
  "su",
  "sy",
  "sz",
  "tc",
  "td",
  "tf",
  "tg",
  "th",
  "tj",
  "tk",
  "tm",
  "tn",
  "to",
  "tp",
  "tr",
  "tt",
  "tv",
  "tw",
  "tz",
  "ua",
  "ug",
  "uk",
  "us",
  "uy",
  "va",
  "vc",
  "ve",
  "vg",
  "vn",
  "vu",
  "wf",
  "ws",
  "ye",
  "yu",
  "za",
  "zm",
  "zr",
  "zw"
];

==> 2.0.0.tar.gz: lib/src/mock_base.dart <==
import 'dart:math';

import 'package:intl/intl.dart';

part 'package:dart_mock/src/data/city.dart';
part 'package:dart_mock/src/random/address.dart';
part 'package:dart_mock/src/random/base.dart';
part 'package:dart_mock/src/random/color.dart';
part 'package:dart_mock/src/random/date.dart';
part 'package:dart_mock/src/random/helper.dart';
part 'package:dart_mock/src/random/image.dart';
part 'package:dart_mock/src/random/miscellaneous.dart';
part 'package:dart_mock/src/random/name.dart';
part 'package:dart_mock/src/random/text.dart';
part 'package:dart_mock/src/random/web.dart';

/// random object.
Random _random = Random();

/// max int value, equal to 2^63-1.
// const int maxInteger = 9223372036854775807;
const int maxInteger = 100;

/// lower case letters.
const String lower = 'abcdefghijklmnopqrstuvwxyz';

/// upper case letters.
const String upper = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ';

/// numbers.
const String number = '0123456789';

/// symbols.
const String symbol = '!@#\$%^&*()[]';

/// chinese regions.
const regions = ['东北', '华北', '华东', '华中', '华南', '西南', '西北'];

/// max dateTime, equal 2099-12-31 23:59:59:999.
const int maxDate = 4102415999999;

/// common ad image sizes.
const List<String> sizes = [
  '300x250',
  '250x250',
  '240x400',
  '336x280',
  '180x150',
  '720x300',
  '468x60',
  '234x60',
  '88x31',
  '120x90',
  '120x60',
  '120x240',
  '125x125',
  '728x90',
  '160x600',
  '120x600',
  '300x600'
];

/// Beyond the top 1000 names, from 'http://www.ssa.gov/oact/babynames/limits.html'.
const List<String> firstNames = [
  // male
  'James',
  'John',
  'Robert',
  'Michael',
  'William',
  'David',
  'Richard',
  'Charles',
  'Joseph',
  'Thomas',
  'Christopher',
  'Daniel',
  'Paul',
  'Mark',
  'Donald',
  'George',
  'Kenneth',
  'Steven',
  'Edward',
  'Brian',
  'Ronald',
  'Anthony',
  'Kevin',
  'Jason',
  'Matthew',
  'Gary',
  'Timothy',
  'Jose',
  'Larry',
  'Jeffrey',
  'Frank',
  'Scott',
  'Eric',
  // female
  'Mary',
  'Patricia',
  'Linda',
  'Barbara',
  'Elizabeth',
  'Jennifer',
  'Maria',
  'Susan',
  'Margaret',
  'Dorothy',
  'Lisa',
  'Nancy',
  'Karen',
  'Betty',
  'Helen',
  'Sandra',
  'Donna',
  'Carol',
  'Ruth',
  'Sharon',
  'Michelle',
  'Laura',
  'Sarah',
  'Kimberly',
  'Deborah',
  'Jessica',
  'Shirley',
  'Cynthia',
  'Angela',
  'Melissa',
  'Brenda',
  'Amy',
  'Anna'
];

// common english lastName.
const List<String> lastNames = [
  'Smith',
  'Johnson',
  'Williams',
  'Brown',
  'Jones',
  'Miller',
  'Davis',
  'Garcia',
  'Rodriguez',
  'Wilson',
  'Martinez',
  'Anderson',
  'Taylor',
  'Thomas',
  'Hernandez',
  'Moore',
  'Martin',
  'Jackson',
  'Thompson',
  'White',
  'Lopez',
  'Lee',
  'Gonzalez',
  'Harris',
  'Clark',
  'Lewis',
  'Robinson',
  'Walker',
  'Perez',
  'Hall',
  'Young',
  'Allen'
];

/// common chinese firstName, from 'http://www.name999.net/xingming/xingshi/20131004/48.html'.
const List<String> cfirstNames = [
  '伟',
  '芳',
  '娜',
  '秀英',
  '敏',
  '静',
  '丽',
  '强',
  '磊',
  '军',
  '洋',
  '勇',
  '艳',
  '杰',
  '娟',
  '涛',
  '明',
  '超',
  '秀兰',
  '霞',
  '平',
  '刚',
  '桂英'
];

/// common chinese lastName, from (http://baike.baidu.com/view/1719115.htm' and 'http://xuanpai.sinaapp.com'.
const List<String> clastNames = [
  '王',
  '李',
  '张',
  '刘',
  '陈',
  '杨',
  '赵',
  '黄',
  '周',
  '吴',
  '徐',
  '孙',
  '胡',
  '朱',
  '高',
  '林',
  '何',
  '郭',
  '马',
  '罗',
  '梁',
  '宋',
  '郑',
  '谢',
  '韩',
  '唐',
  '冯',
  '于',
  '董',
  '萧',
  '程',
  '曹',
  '袁',
  '邓',
  '许',
  '傅',
  '沈',
  '曾',
  '彭',
  '吕',
  '苏',
  '卢',
  '蒋',
  '蔡',
  '贾',
  '丁',
  '魏',
  '薛',
  '叶',
  '阎',
  '余',
  '潘',
  '杜',
  '戴',
  '夏',
  '锺',
  '汪',
  '田',
  '任',
  '姜',
  '范',
  '方',
  '石',
  '姚',
  '谭',
  '廖',
  '邹',
  '熊',
  '金',
  '陆',
  '郝',
  '孔',
  '白',
  '崔',
  '康',
  '毛',
  '邱',
  '秦',
  '江',
  '史',
  '顾',
  '侯',
  '邵',
  '孟',
  '龙',
  '万',
  '段',
  '雷',
  '钱',
  '汤',
  '尹',
  '黎',
  '易',
  '常',
  '武',
  '乔',
  '贺',
  '赖',
  '龚',
  '文'
];

/// Commonly used 500 Chinese characters, from 'http://baike.baidu.com/view/568436.htm'.
const String chineseCharacters =
    '的一是在不了有和人这中大为上个国我以要他时来用们生到作地于出就分对成会可主发年动同工也能下过子说产种面而方后多定行学法所民得经十三之进着等部度家电力里如水化高自二理起小物现实加量都两体制机当使点从业本去把性好应开它合还因由其些然前外天政四日那社义事平形相全表间样与关各重新线内数正心反你明看原又么利比或但质气第向道命此变条只没结解问意建月公无系军很情者最立代想已通并提直题党程展五果料象员革位入常文总次品式活设及管特件长求老头基资边流路级少图山统接知较将组见计别她手角期根论运农指几九区强放决西被干做必战先回则任取据处队南给色光门即保治北造百规热领七海口东导器压志世金增争济阶油思术极交受联什认六共权收证改清己美再采转更单风切打白教速花带安场身车例真务具万每目至达走积示议声报斗完类八离华名确才科张信马节话米整空元况今集温传土许步群广石记需段研界拉林律叫且究观越织装影算低持音众书布复容儿须际商非验连断深难近矿千周委素技备半办青省列习响约支般史感劳便团往酸历市克何除消构府称太准精值号率族维划选标写存候毛亲快效斯院查江型眼王按格养易置派层片始却专状育厂京识适属圆包火住调满县局照参红细引听该铁价严龙飞';

/// common protocols.
const List<String> protocols = [
  'http',
  'https',
  'ftp',
  'gopher',
  'mailto',
  'mid',
  'cid',
  'news',
  'nntp',
  'prospero',
  'telnet',
  'rlogin',
  'tn3270',
  'wais'
];

/// common tlds, from 'http://www.163ns.com/zixun/post/4417.html'.
const List<String> tlds = [
  // common
  'com',
  'net',
  'org',
  'edu',
  'gov',
  'int',
  'mil',
  'cn',
  // domestic
  'com.cn',
  'net.cn',
  'gov.cn',
  'org.cn',
  // chinese tlds.
  '中国',
  '中国互联.公司',
  '中国互联.网络',
  // new international tlds.
  'tel',
  'biz',
  'cc',
  'tv',
  'info',
  'name',
  'hk',
  'mobi',
  'asia',
  'cd',
  'travel',
  'pro',
  'museum',
  'coop',
  'aero',
  // other country or territory tlds.
  'ad',
  'ae',
  'af',
  'ag',
  'ai',
  'al',
  'am',
  'an',
  'ao',
  'aq',
  'ar',
  'as',
  'at',
  'au',
  'aw',
  'az',
  'ba',
  'bb',
  'bd',
  'be',
  'bf',
  'bg',
  'bh',
  'bi',
  'bj',
  'bm',
  'bn',
  'bo',
  'br',
  'bs',
  'bt',
  'bv',
  'bw',
  'by',
  'bz',
  'ca',
  'cc',
  'cf',
  'cg',
  'ch',
  'ci',
  'ck',
  'cl',
  'cm',
  'cn',
  'co',
  'cq',
  'cr',
  'cu',
  'cv',
  'cx',
  'cy',
  'cz',
  'de',
  'dj',
  'dk',
  'dm',
  'do',
  'dz',
  'ec',
  'ee',
  'eg',
  'eh',
  'es',
  'et',
  'ev',
  'fi',
  'fj',
  'fk',
  'fm',
  'fo',
  'fr',
  'ga',
  'gb',
  'gd',
  'ge',
  'gf',
  'gh',
  'gi',
  'gl',
  'gm',
  'gn',
  'gp',
  'gr',
  'gt',
  'gu',
  'gw',
  'gy',
  'hk',
  'hm',
  'hn',
  'hr',
  'ht',
  'hu',
  'id',
  'ie',
  'il',
  'in',
  'io',
  'iq',
  'ir',
  'is',
  'it',
  'jm',
  'jo',
  'jp',
  'ke',
  'kg',
  'kh',
  'ki',
  'km',
  'kn',
  'kp',
  'kr',
  'kw',
  'ky',
  'kz',
  'la',
  'lb',
  'lc',
  'li',
  'lk',
  'lr',
  'ls',
  'lt',
  'lu',
  'lv',
  'ly',
  'ma',
  'mc',
  'md',
  'mg',
  'mh',
  'ml',
  'mm',
  'mn',
  'mo',
  'mp',
  'mq',
  'mr',
  'ms',
  'mt',
  'mv',
  'mw',
  'mx',
  'my',
  'mz',
  'na',
  'nc',
  'ne',
  'nf',
  'ng',
  'ni',
  'nl',
  'no',
  'np',
  'nr',
  'nt',
  'nu',
  'nz',
  'om',
  'qa',
  'pa',
  'pe',
  'pf',
  'pg',
  'ph',
  'pk',
  'pl',
  'pm',
  'pn',
  'pr',
  'pt',
  'pw',
  'py',
  're',
  'ro',
  'ru',
  'rw',
  'sa',
  'sb',
  'sc',
  'sd',
  'se',
  'sg',
  'sh',
  'si',
  'sj',
  'sk',
  'sl',
  'sm',
  'sn',
  'so',
  'sr',
  'st',
  'su',
  'sy',
  'sz',
  'tc',
  'td',
  'tf',
  'tg',
  'th',
  'tj',
  'tk',
  'tm',
  'tn',
  'to',
  'tp',
  'tr',
  'tt',
  'tv',
  'tw',
  'tz',
  'ua',
  'ug',
  'uk',
  'us',
  'uy',
  'va',
  'vc',
  've',
  'vg',
  'vn',
  'vu',
  'wf',
  'ws',
  'ye',
  'yu',
  'za',
  'zm',
  'zr',
  'zw'
];
